#!/bin/bash

# Copyright (C) since 2014 NTT DATA Corporation
#
# This program is free software; you can redistribute it and/or
# Modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation, version 2.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details

# bash configuration
SCRIPT_DIR=$(cd $(dirname $0);pwd)
PROG=`basename $0`

########################################
#  Local Variable
########################################

# script version
SCRIPT_VERSION="1.0.0"

########################################
# Function
########################################
#
# Message Logging
#
function Logging() {
	[ "x${QUIET}" != "xtrue" ] && echo "$1"
	/usr/bin/logger "${PROG} $1"
}

#
# show usage
#
function usage {
	echo "usage : ${PROG} -s SESSIONID -q [--version] [--help]"
	echo "options:"
	echo "  -s SESSIONID    set a job session id"
	echo "  -q              quiet mode"
	echo "  --version       show version"
	echo "  --help          show usage"
}

########################################
# SHELL
########################################

# help chekc
for OPT in $@
do
	case $OPT in
		--version)
			echo ${SCRIPT_VERSION}
			exit 0
			;;
		--help)
			usage
			exit 0
			;;
	esac
done

# check parameters
while getopts ":s:q" OPT
do
	case ${OPT} in
		s)
			SESSIONID=${OPTARG}
			;;
		q)
			QUIET=true
			;;
		*)
			usage
			exit 1
			;;
	esac
done

shift $((OPTIND - 1))

# check
if [ ! -n "${SESSIONID}" ]; then
	echo "option (-s) is not specified."
	usage
	exit 1
fi
Logging "target session id ${SESSIONID}"

# delete message file
MESSAGE_FILE="/tmp/aws_sqs_${SESSIONID}.txt"
if [ -e ${MESSAGE_FILE} ]; then
	rm -f ${MESSAGE_FILE}
	RET=$?
	if [ ${RET} -eq 0 ]; then
		Logging "${MESSAGE_FILE} file delete success"
	else
		Logging "${MESSAGE_FILE} file delete failed"
		exit 1
	fi
else
	Logging "${MESSAGE_FILE} file not found"
fi

########################################
# Termination Processing
########################################
exit 0

